@@ -289,6 +289,12 @@
                     themeEvents.push(handler);
                 } else if (name == 'font') {
                     fontEvents.push(handler);
+                }else if(name=='title'){
+                    app.tabs.forEach(item=>{
+                        if(item.eid==app.tabModel){
+                            item.name = handler;
+                        }
+                    })
                 }
             }
             var temp_tabs = sessionStorage['tabs'];
@@ -374,15 +380,27 @@
                 window.open(url);
             },
             contextmenu: function (item, e) {
+                //右键菜单，如果x+菜单宽度超过屏幕宽度，就默认为屏幕宽度-10-菜单宽度
 
                 //home没有popup menu
                 if (item.id == '0') {
                     return;
                 }
                 this.popup.tab = item;
-                this.popup.left = e.clientX;
-                this.popup.top = e.clientY;
                 this.popup.show = true;
+                this.$nextTick(function () {
+                    let el = this.$refs.popupmenu;
+                    el.style.width='150px';
+                    let x = e.clientX;
+
+                    let w= document.body.offsetWidth
+                    if(x+150>w){
+                        x = w - 160;
+                    }
+
+                    this.popup.left = x;
+                    this.popup.top = e.clientY;
+                });
             },
             mainClick: function (e) {
                 this.popup.show = false;
@@ -572,7 +590,7 @@
             },
             report: function (url) {
                 if (!url) {
-                    if ($("html").lang) {
+                    if (document.querySelector('html').lang) {
                         url = 'https://simpleui.88cto.com';
                     } else {
                         url = 'https://github.com/newpanjing/simpleui/issues';
